@@ -27,10 +27,7 @@ class Controller:
         self._config = Config("/apps/youamp/")
         self._check_config()
         self._player = Player(self._config)
-        self._library = Library()
-        
-        self._refresh_playlist()
-        
+        self._library = Library()        
         self._window = Window(self._player, self._config, self._library)
         self._banner = None
         self._scrobbler = None
@@ -43,11 +40,7 @@ class Controller:
         gobject.set_application_name("YouAmp")
    
         # last.fm submission
-        if self._config["lastfm-user"] != "":
-            try:
-                self._scrobbler = scrobbler.Scrobbler(self._config["lastfm-user"], self._config["lastfm-pass"], ("you", VERSION))
-            except (urllib2.URLError, scrobbler.AuthError), e:
-                sys.stderr.write("lastfm.login: %s\n" % e)
+        self._scrobbler = scrobbler.Scrobbler(self._config["lastfm-user"], self._config["lastfm-pass"], ("you", VERSION))
             
         # RPC
         if IS_MAEMO:
@@ -63,14 +56,9 @@ class Controller:
         # menu
         menu = Menu(self._config)
         self._window.set_menu(menu)
-                
-        if self._config["shuffle"]:
-            self._player.playlist.shuffle(True)
-
-        # restore config
-        if self._player.tracks() > 0:
-            self._player.load_track()
-
+        
+        self._restore()
+        
         # menu signals
         menu.prefs.connect("activate", self._show_preferences)
         menu.about.connect("activate", self._show_about_dialog)
@@ -92,6 +80,18 @@ class Controller:
         # start updating library
         self._refresh_library()
     
+    def _restore(self):
+        self._refresh_playlist()
+ 
+        if self._config["shuffle"]:
+            self._player.playlist.shuffle(True)
+
+        # restore config
+        if self._player.tracks() > 0:
+            self._player.load_track()
+        
+        self._window.view.restore()
+    
     def _refresh_library(self, *args):
         self._banner = hildon.hildon_banner_show_animation(self._window, "qgn_indi_pball_a", _("Updating database"))
         self._library.update(self._config["music-folder"])
