@@ -171,8 +171,8 @@ class Library(GObject):
             if song["title"] == "None" and \
                song["artist"] == "None" and \
                song["album"] == "None":
-                    fname = self.uri.rindex("/")
-                    fnend = self.uri.rindex(".")
+                    fname = song.uri.rindex("/")
+                    fnend = song.uri.rindex(".")
                     song["title"] = uri[fname+1:fnend]
             else:
                 # sanitise tags
