@@ -36,15 +36,17 @@ class Player(GObject):
         self._config.notify_add("rg-preamp", lambda client, cxn_id, entry, data: self._apply_volume())
         self._config.notify_add("no-rg-preamp", lambda client, cxn_id, entry, data: self._apply_volume())
 
-    def next(self, bus=None, message=None):        
-        self._config["pos"] = (self._config["pos"] + 1) % len(self.playlist)        
+    def next(self, bus=None, message=None):
+        self._config["pos"] = (self._config["pos"] + 1) % len(self.playlist)
+        # FIXME: maemo does not see the update otherwise
+        self._config.notify("pos")        
         self.start_playback()
 
     def tracks(self):
         return len(self.playlist)
 
     def goto_pos(self, pos):
-        self._config["pos"] = pos % len(self.playlist)        
+        self._config["pos"] = pos % len(self.playlist)   
         self.start_playback()
 
     def previous(self):
@@ -53,7 +55,9 @@ class Player(GObject):
             self.seek_to(0.0)
             return
 
-        self._config["pos"] = (self._config["pos"] - 1) % len(self.playlist)        
+        self._config["pos"] = (self._config["pos"] - 1) % len(self.playlist)
+        # FIXME: maemo does not see the update otherwise
+        self._config.notify("pos")    
         self.start_playback()
     
     def get_time(self):
@@ -99,6 +103,8 @@ class Player(GObject):
         if self._player is not None:
             self._player.set_state(gst.STATE_NULL)
         
+        # FIXME Maemo needs the playbin to be recreated every time
+        # a new file is loaded
         self._player = gst.element_factory_make("playbin")
         
         bus = self._player.get_bus()
@@ -122,7 +128,7 @@ class Player(GObject):
             if state[0:2] == [gst.STATE_READY, gst.STATE_PAUSED]:
                 self._apply_volume()
                 
-                # FIXME actually duration should be set here
+                # FIXME duration should be set directly here
                 if self._set_duration_id is not None:
                     gobject.source_remove(self._set_duration_id)
                 self._set_duration_id = gobject.timeout_add(1000, self._set_duration)
