@@ -188,7 +188,6 @@ class SearchView(gtk.VBox):
         self._artist.show()
 
         self._album.hide()
-        print "search-artist changed"
 
     def _on_search_album(self, client, cxn_id, entry, data):
         val = entry.get_value().get_string()
@@ -199,7 +198,6 @@ class SearchView(gtk.VBox):
         self._album.show()
         
         self._browse_complete()
-        print "search-album changed"
 
     def _select_album(self, caller):        
         if not (self._browser._state & ALBUM_SELECTED):
